from poimage.api.image import *

print('*' * 10)
print('【Python自动化办公】，功能持续更新中')
print('使用有问题 or 提交你的功能需求 or 参与项目开发')
print('1、给小白的【50讲Python自动化办公】：https://mp.weixin.qq.com/s/naqnxjkrhvDtoCnzlRIO1Q')
print('2、请+【项目交流群】：http://t.cn/A65MiFvH')
print('3、本开源项目的【源代码】：https://github.com/CoderWanFeng/python-office')
print('*' * 10)
